"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
exports.__esModule = true;
exports.assetFieldResolver = exports.namespacedTypeName = exports.namespace = exports.GraphQLNever = void 0;
var graphql_1 = require("graphql");
var inflection_1 = __importDefault(require("inflection"));
exports.GraphQLNever = new graphql_1.GraphQLScalarType({
    name: 'Never'
});
function namespace(ns) {
    var namespaceName = ns ? inflection_1["default"].titleize(ns) : undefined;
    var GraphQLLocation = new graphql_1.GraphQLObjectType({
        name: toType('Location'),
        fields: {
            lat: { type: graphql_1.GraphQLFloat },
            lon: { type: graphql_1.GraphQLFloat }
        }
    });
    var Sys = new graphql_1.GraphQLObjectType({
        name: toType('Sys'),
        fields: {
            id: { type: graphql_1.GraphQLString },
            spaceId: { type: graphql_1.GraphQLString },
            environmentId: { type: graphql_1.GraphQLString }
        }
    });
    var ContentfulTag = new graphql_1.GraphQLObjectType({
        name: toType('ContentfulTag'),
        fields: {
            id: { type: new graphql_1.GraphQLNonNull(graphql_1.GraphQLString) },
            name: { type: new graphql_1.GraphQLNonNull(graphql_1.GraphQLString) }
        }
    });
    var ContentfulMetadata = new graphql_1.GraphQLObjectType({
        name: toType('ContentfulMetadata'),
        fields: {
            tags: { type: new graphql_1.GraphQLNonNull(new graphql_1.GraphQLList(ContentfulTag)) }
        }
    });
    var Entry = new graphql_1.GraphQLInterfaceType({
        name: toType('Entry'),
        fields: {
            sys: { type: Sys },
            contentfulMetadata: { type: ContentfulMetadata }
        }
    });
    var EntryCollection = new graphql_1.GraphQLObjectType({
        name: toType('EntryCollection'),
        fields: {
            skip: { type: new graphql_1.GraphQLNonNull(graphql_1.GraphQLInt) },
            limit: { type: new graphql_1.GraphQLNonNull(graphql_1.GraphQLInt) },
            total: { type: new graphql_1.GraphQLNonNull(graphql_1.GraphQLInt) },
            items: { type: new graphql_1.GraphQLNonNull(new graphql_1.GraphQLList(Entry)) }
        }
    });
    var Asset = new graphql_1.GraphQLObjectType({
        name: toType('Asset'),
        fields: {
            sys: { type: Sys },
            contentfulMetadata: { type: ContentfulMetadata },
            // linkedFrom: AssetLinkingCollections
            title: { type: graphql_1.GraphQLString },
            description: { type: graphql_1.GraphQLString },
            contentType: { type: graphql_1.GraphQLString },
            fileName: { type: graphql_1.GraphQLString },
            url: { type: graphql_1.GraphQLString },
            size: { type: graphql_1.GraphQLInt },
            width: { type: graphql_1.GraphQLInt },
            height: { type: graphql_1.GraphQLInt }
        }
    });
    var AssetCollection = new graphql_1.GraphQLObjectType({
        name: toType('AssetCollection'),
        fields: {
            skip: { type: new graphql_1.GraphQLNonNull(graphql_1.GraphQLInt) },
            limit: { type: new graphql_1.GraphQLNonNull(graphql_1.GraphQLInt) },
            total: { type: new graphql_1.GraphQLNonNull(graphql_1.GraphQLInt) },
            items: { type: new graphql_1.GraphQLNonNull(new graphql_1.GraphQLList(Asset)) }
        }
    });
    return {
        _name: namespaceName,
        Asset: Asset,
        AssetCollection: AssetCollection,
        ContentfulMetadata: ContentfulMetadata,
        ContentfulTag: ContentfulTag,
        Entry: Entry,
        EntryCollection: EntryCollection,
        Sys: Sys,
        GraphQLLocation: GraphQLLocation,
        toType: toType
    };
    function toType(name) {
        return namespacedTypeName(name, namespaceName);
    }
}
exports.namespace = namespace;
function namespacedTypeName(name, namespace) {
    if (namespace && !name.startsWith(namespace + '_')) {
        name = namespace + "_" + name;
    }
    return name;
}
exports.namespacedTypeName = namespacedTypeName;
function assetFieldResolver() {
    return {
        title: function (asset) { return asset.fields.title; },
        description: function (asset) { return asset.fields.description; },
        contentType: function (asset) { var _a; return (_a = asset.fields.file) === null || _a === void 0 ? void 0 : _a.contentType; },
        fileName: function (asset) { var _a; return (_a = asset.fields.file) === null || _a === void 0 ? void 0 : _a.fileName; },
        url: function (asset) { var _a; return (_a = asset.fields.file) === null || _a === void 0 ? void 0 : _a.url; },
        size: function (asset) { var _a, _b; return (_b = (_a = asset.fields.file) === null || _a === void 0 ? void 0 : _a.details) === null || _b === void 0 ? void 0 : _b.size; },
        width: function (asset) { var _a, _b, _c; return (_c = (_b = (_a = asset.fields.file) === null || _a === void 0 ? void 0 : _a.details) === null || _b === void 0 ? void 0 : _b.image) === null || _c === void 0 ? void 0 : _c.width; },
        height: function (asset) { var _a, _b, _c; return (_c = (_b = (_a = asset.fields.file) === null || _a === void 0 ? void 0 : _a.details) === null || _b === void 0 ? void 0 : _b.image) === null || _c === void 0 ? void 0 : _c.height; }
    };
}
exports.assetFieldResolver = assetFieldResolver;
//# sourceMappingURL=types.js.map